import { ChallengeService } from './../Challenge/ChallengeService';
import { DecryptedItem, DecryptedItemInterface, FileItem, SNNote } from '@standardnotes/models';
import { DiskStorageService } from '../Storage/DiskStorageService';
import { AbstractService, InternalEventBusInterface, Challenge, ChallengeReason, EncryptionService, MobileUnlockTiming, TimingDisplayOption, ProtectionsClientInterface, MutatorClientInterface, InternalEventHandlerInterface, InternalEventInterface, ProtectionEvent } from '@standardnotes/services';
/**
 * Enforces certain actions to require extra authentication,
 * like viewing a protected note, as well as managing how long that
 * authentication should be valid for.
 */
export declare class ProtectionService extends AbstractService<ProtectionEvent> implements ProtectionsClientInterface, InternalEventHandlerInterface {
    private encryption;
    private mutator;
    private challenges;
    private storage;
    protected internalEventBus: InternalEventBusInterface;
    private sessionExpiryTimeout;
    private mobilePasscodeTiming;
    private mobileBiometricsTiming;
    private isBiometricsSoftLockEngaged;
    private applicationStarted;
    constructor(encryption: EncryptionService, mutator: MutatorClientInterface, challenges: ChallengeService, storage: DiskStorageService, internalEventBus: InternalEventBusInterface);
    deinit(): void;
    handleEvent(event: InternalEventInterface): Promise<void>;
    isLocked(): Promise<boolean>;
    softLockBiometrics(): void;
    hasProtectionSources(): boolean;
    hasUnprotectedAccessSession(): boolean;
    hasBiometricsEnabled(): boolean;
    enableBiometrics(): boolean;
    disableBiometrics(): Promise<boolean>;
    createLaunchChallenge(): Challenge | undefined;
    authorizeProtectedActionForItems<T extends DecryptedItem>(items: T[], challengeReason: ChallengeReason): Promise<T[]>;
    authorizeItemAccess(item: DecryptedItem): Promise<boolean>;
    authorizeAddingPasscode(): Promise<boolean>;
    authorizeChangingPasscode(): Promise<boolean>;
    authorizeRemovingPasscode(): Promise<boolean>;
    authorizeSearchingProtectedNotesText(): Promise<boolean>;
    authorizeFileImport(): Promise<boolean>;
    authorizeBackupCreation(): Promise<boolean>;
    authorizeMfaDisable(): Promise<boolean>;
    authorizeAutolockIntervalChange(): Promise<boolean>;
    authorizeSessionRevoking(): Promise<boolean>;
    authorizeListedPublishing(): Promise<boolean>;
    authorizeAction(reason: ChallengeReason, dto: {
        fallBackToAccountPassword: boolean;
        requireAccountPassword: boolean;
        forcePrompt: boolean;
    }): Promise<boolean>;
    getMobilePasscodeTimingOptions(): TimingDisplayOption[];
    getMobileBiometricsTimingOptions(): TimingDisplayOption[];
    getMobileBiometricsTiming(): MobileUnlockTiming | undefined;
    getMobilePasscodeTiming(): MobileUnlockTiming | undefined;
    setMobileBiometricsTiming(timing: MobileUnlockTiming): void;
    setMobilePasscodeTiming(timing: MobileUnlockTiming): void;
    setMobileScreenshotPrivacyEnabled(isEnabled: boolean): void;
    getMobileScreenshotPrivacyEnabled(): boolean;
    private validateOrRenewSession;
    getSessionExpiryDate(): Date;
    clearSession(): Promise<void>;
    private setSessionExpiryDate;
    private getLastSessionLength;
    private setSessionLength;
    private updateSessionExpiryTimer;
    protectItems<I extends DecryptedItemInterface>(items: I[]): Promise<I[]>;
    unprotectItems<I extends DecryptedItemInterface>(items: I[], reason: ChallengeReason): Promise<I[] | undefined>;
    protectNote(note: SNNote): Promise<SNNote>;
    unprotectNote(note: SNNote): Promise<SNNote | undefined>;
    protectNotes(notes: SNNote[]): Promise<SNNote[]>;
    unprotectNotes(notes: SNNote[]): Promise<SNNote[]>;
    protectFile(file: FileItem): Promise<FileItem>;
    unprotectFile(file: FileItem): Promise<FileItem | undefined>;
}
