import { ServerSyncPushContextualPayload } from '@standardnotes/models';
import { ServerSyncResponse } from './Response';
import { ResponseSignalReceiver } from '../Signals';
import { LegacyApiService } from '../../Api/ApiService';
export declare const SyncUpDownLimit = 150;
/**
 * A long running operation that handles multiple roundtrips from a server,
 * emitting a stream of values that should be acted upon in real time.
 */
export declare class AccountSyncOperation {
    readonly payloads: ServerSyncPushContextualPayload[];
    private receiver;
    private apiService;
    readonly options: {
        syncToken?: string;
        paginationToken?: string;
        sharedVaultUuids?: string[];
    };
    readonly id: string;
    private pendingPayloads;
    private responses;
    /**
     * @param payloads   An array of payloads to send to the server
     * @param receiver   A function that receives callback multiple times during the operation
     */
    constructor(payloads: ServerSyncPushContextualPayload[], receiver: ResponseSignalReceiver<ServerSyncResponse>, apiService: LegacyApiService, options: {
        syncToken?: string;
        paginationToken?: string;
        sharedVaultUuids?: string[];
    });
    /**
     * Read the payloads that have been saved, or are currently in flight.
     */
    get payloadsSavedOrSaving(): ServerSyncPushContextualPayload[];
    popPayloads(count: number): ServerSyncPushContextualPayload[];
    run(): Promise<void>;
    get done(): boolean;
    private get pendingUploadCount();
    private get totalUploadCount();
    private get upLimit();
    private get downLimit();
    get numberOfItemsInvolved(): number;
}
